@@ -1,5 +1,8 @@
 package Finance::Bank::ID::Mandiri;
 
+our $DATE = '2015-02-06'; # DATE
+our $VERSION = '0.31'; # VERSION
+
 use 5.010001;
 
 use Moo;
@@ -9,8 +12,6 @@ use HTTP::Headers;
 use HTTP::Headers::Patch::DontUseStorable -load_target=>0;
 extends 'Finance::Bank::ID::Base';
 
-our $VERSION = '0.30'; # VERSION
-
 has _variant => (is => 'rw');
 has _re_tx   => (is => 'rw');
 
@@ -624,7 +625,7 @@ Finance::Bank::ID::Mandiri - Check your Bank Mandiri accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.30 of Finance::Bank::ID::Mandiri (from Perl distribution Finance-Bank-ID-Mandiri), released on 2014-10-15.
+This document describes version 0.31 of Finance::Bank::ID::Mandiri (from Perl distribution Finance-Bank-ID-Mandiri), released on 2015-02-06.
 
 =head1 SYNOPSIS
 
@@ -715,9 +716,6 @@ GUARANTEE>, explicit or implied.
 
 Most methods die() when encountering errors, so you can use eval() to trap them.
 
-This module uses L<Log::Any>, so you can see more debugging statements on
-your screen, log files, etc.
-
 Full response headers and bodies are dumped to a separate logger. See
 documentation on C<new()> below and the sample script in examples/ subdirectory
 in the distribution.
@@ -919,7 +917,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
